(using-layers)=
# Using layers

[Layers](napari.layers) are the viewable objects that can be added to a viewer.
To learn about how to use the layers currently supported by napari, check the
following how-to guides:

```{tableofcontents}
```

For a high-level overview of the napari Layers, see
[Layers at a glance](../../guides/layers).